<?php

namespace Drupal\openai_batch\Plugin\Action;

use Drupal\ai\Plugin\ProviderProxy;
use Drupal\Core\Form\FormStateInterface;
use Drupal\openai_batch\DTO\OpenAiBatchRequestItemConfig;

/**
 * Interface for OpenAI Batch VBO actions.
 */
interface OpenAiBatchVBOActionInterface {

  /**
   * Get the command to send to OpenAI for a single entity.
   *
   * @param string $entity_type
   *   The entity type ID of the entity to process.
   * @param string $entity_id
   *   The entity ID of the entity to process.
   * @param \Drupal\openai_batch\DTO\OpenAiBatchRequestItemConfig $request_item_config
   *   The configuration for the request.
   */
  public function getOpenAiBatchCommandForEntity(string $entity_type, string $entity_id, OpenAiBatchRequestItemConfig $request_item_config): array;

  /**
   * Proxy method for the VBO preconfiguration form.
   *
   * @see \Drupal\views_bulk_operations\Action\ViewsBulkOperationsPreconfigurationInterface::buildPreConfigurationForm
   */
  public function buildPreConfigurationForm(array $element, array $values, FormStateInterface $form_state): array;

  /**
   * Proxy method for the end user configuration form.
   *
   * @see \Drupal\Core\Plugin\PluginFormInterface::buildConfigurationForm
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state, array $vbo_context, ProviderProxy $llm_instance): array;

  /**
   * Proxy method for the configuration form validation.
   *
   * @see \Drupal\Core\Plugin\PluginFormInterface::validateConfigurationForm
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state): void;

}
